summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--plugin/smb4k_konqplugin.cpp2
-rw-r--r--smb4k/browser/smb4knetworkbrowser_part.cpp22
-rw-r--r--smb4k/configdlg/smb4kconfigdialog.cpp4
-rw-r--r--smb4k/core/smb4kcore.cpp6
-rw-r--r--smb4k/core/smb4kfileio.cpp60
-rw-r--r--smb4k/core/smb4kfileio.h4
-rw-r--r--smb4k/core/smb4khomesshareshandler.cpp2
-rw-r--r--smb4k/core/smb4kmounter.cpp74
-rw-r--r--smb4k/core/smb4kpasswordhandler.cpp16
-rw-r--r--smb4k/core/smb4kpreviewer.cpp8
-rw-r--r--smb4k/core/smb4kprint.cpp14
-rw-r--r--smb4k/core/smb4ksambaoptionshandler.cpp4
-rw-r--r--smb4k/core/smb4ksambaoptionsinfo.cpp2
-rw-r--r--smb4k/core/smb4kscanner.cpp76
-rw-r--r--smb4k/core/smb4ksynchronizationinfo.h2
-rw-r--r--smb4k/core/smb4ksynchronizer.cpp12
-rw-r--r--smb4k/dialogs/smb4kmountdialog.cpp6
-rw-r--r--smb4k/dialogs/smb4kpreviewdialog.cpp10
-rw-r--r--smb4k/iconview/smb4ksharesiconview.cpp8
-rw-r--r--smb4k/main.cpp12
-rw-r--r--smb4k/searchdlg/smb4ksearchdialog.cpp2
-rw-r--r--smb4k/smb4k.cpp2
-rw-r--r--smb4k/smb4ksystemtray.cpp4
-rw-r--r--utilities/smb4k_kill.cpp2
-rw-r--r--utilities/smb4k_mount.cpp2
-rw-r--r--utilities/smb4k_mv.cpp2
-rw-r--r--utilities/smb4k_umount.cpp2
27 files changed, 180 insertions, 180 deletions
diff --git a/plugin/smb4k_konqplugin.cpp b/plugin/smb4k_konqplugin.cpp
index e66ba97..794482c 100644
--- a/plugin/smb4k_konqplugin.cpp
+++ b/plugin/smb4k_konqplugin.cpp
@@ -68,7 +68,7 @@ KonqSidebar_Smb4K::KonqSidebar_Smb4K(KInstance *inst,TQObject *tqparent,TQWidget
KToolBar *topBar = new KToolBar( widget, "Topbar" );
topBar->setIconSize(16);
topBar->insertButton( "reload", 0, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotRescan() ) , TRUE, i18n( "Scan Network" ) );
- topBar->insertButton( "tqfind", 1, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotSearch() ) , TRUE, i18n( "Search" ) );
+ topBar->insertButton( "find", 1, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotSearch() ) , TRUE, i18n( "Search" ) );
topBar->insertButton( "configure", 2, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotSmb4KOptionsDlg() ) , TRUE, i18n( "Configure" ) );
//
diff --git a/smb4k/browser/smb4knetworkbrowser_part.cpp b/smb4k/browser/smb4knetworkbrowser_part.cpp
index e6e1225..6d1346c 100644
--- a/smb4k/browser/smb4knetworkbrowser_part.cpp
+++ b/smb4k/browser/smb4knetworkbrowser_part.cpp
@@ -733,8 +733,8 @@ void Smb4KNetworkBrowserPart::slotWorkgroups( const TQValueList<Smb4KWorkgroupIt
if ( TQString::compare( old_master, (*i)->master() ) != 0 && item->isOpen() )
{
// Get the list view items:
- Smb4KNetworkBrowserItem *oldMasterItem = static_cast<Smb4KNetworkBrowserItem *>( m_widget->tqfindItem( old_master, Smb4KNetworkBrowser::Network, CaseSensitive|ExactMatch ) );
- Smb4KNetworkBrowserItem *newMasterItem = static_cast<Smb4KNetworkBrowserItem *>( m_widget->tqfindItem( (*i)->master(), Smb4KNetworkBrowser::Network, CaseSensitive|ExactMatch ) );
+ Smb4KNetworkBrowserItem *oldMasterItem = static_cast<Smb4KNetworkBrowserItem *>( m_widget->findItem( old_master, Smb4KNetworkBrowser::Network, CaseSensitive|ExactMatch ) );
+ Smb4KNetworkBrowserItem *newMasterItem = static_cast<Smb4KNetworkBrowserItem *>( m_widget->findItem( (*i)->master(), Smb4KNetworkBrowser::Network, CaseSensitive|ExactMatch ) );
// Get the host item of the new master from the scanner. The old master
// has been removed from the internal host list, so we cannot search for
@@ -778,7 +778,7 @@ void Smb4KNetworkBrowserPart::slotWorkgroups( const TQValueList<Smb4KWorkgroupIt
{
// Is the list entry in the list view? If not, add it to the list
// view. (If it is, it will be found and updated by the code above.)
- if ( m_widget->tqfindItem( (*i)->name(), Smb4KNetworkBrowser::Network, CaseSensitive|ExactMatch ) == 0 )
+ if ( m_widget->findItem( (*i)->name(), Smb4KNetworkBrowser::Network, CaseSensitive|ExactMatch ) == 0 )
{
Smb4KNetworkBrowserItem *workgroup = new Smb4KNetworkBrowserItem( m_widget, *i );
workgroup->setExpandable( true );
@@ -834,7 +834,7 @@ void Smb4KNetworkBrowserPart::slotWorkgroupMembers( const TQString &workgroup, c
if ( !workgroup.isEmpty() )
{
- workgroupItem = static_cast<Smb4KNetworkBrowserItem *>( m_widget->tqfindItem( workgroup, Smb4KNetworkBrowser::Network, ExactMatch|CaseSensitive ) );
+ workgroupItem = static_cast<Smb4KNetworkBrowserItem *>( m_widget->findItem( workgroup, Smb4KNetworkBrowser::Network, ExactMatch|CaseSensitive ) );
}
else
{
@@ -880,7 +880,7 @@ void Smb4KNetworkBrowserPart::slotWorkgroupMembers( const TQString &workgroup, c
// scanner, we need omit all entries that do not belong to this
// workgroup.
if ( TQString::compare( (*i)->workgroup(), workgroupItem->workgroupItem()->name() ) == 0 &&
- m_widget->tqfindItem( (*i)->name(), Smb4KNetworkBrowser::Network, CaseSensitive|ExactMatch ) == 0 )
+ m_widget->findItem( (*i)->name(), Smb4KNetworkBrowser::Network, CaseSensitive|ExactMatch ) == 0 )
{
Smb4KNetworkBrowserItem *hostItem = new Smb4KNetworkBrowserItem( workgroupItem, *i );
hostItem->setExpandable( true );
@@ -960,7 +960,7 @@ void Smb4KNetworkBrowserPart::slotShares( const TQString &host, const TQValueLis
if ( !host.isEmpty() )
{
- hostItem = static_cast<Smb4KNetworkBrowserItem *>( m_widget->tqfindItem( host, Smb4KNetworkBrowser::Network, ExactMatch|CaseSensitive ) );
+ hostItem = static_cast<Smb4KNetworkBrowserItem *>( m_widget->findItem( host, Smb4KNetworkBrowser::Network, ExactMatch|CaseSensitive ) );
}
else
{
@@ -1079,7 +1079,7 @@ void Smb4KNetworkBrowserPart::slotShares( const TQString &host, const TQValueLis
{
// Does the host carry the list entry? If not, add it to it.
// (If it is, it will be found and updated by the code above.)
- if ( m_widget->tqfindItem( (*i)->name(), Smb4KNetworkBrowser::Network, CaseSensitive|ExactMatch ) == 0 )
+ if ( m_widget->findItem( (*i)->name(), Smb4KNetworkBrowser::Network, CaseSensitive|ExactMatch ) == 0 )
{
// Respect the settings the user chose to use:
if ( !(*i)->isHidden() )
@@ -1244,7 +1244,7 @@ void Smb4KNetworkBrowserPart::slotAddIPAddress( Smb4KHostItem *item )
{
// Get the workgroup item the server is a child of and update
// it.
- Smb4KNetworkBrowserItem *workgroup_item = static_cast<Smb4KNetworkBrowserItem *>( m_widget->tqfindItem( item->workgroup(), Smb4KNetworkBrowser::Network, ExactMatch|CaseSensitive ) );
+ Smb4KNetworkBrowserItem *workgroup_item = static_cast<Smb4KNetworkBrowserItem *>( m_widget->findItem( item->workgroup(), Smb4KNetworkBrowser::Network, ExactMatch|CaseSensitive ) );
if ( workgroup_item && TQString::compare( workgroup_item->workgroupItem()->name(), item->workgroup() ) == 0 )
{
@@ -1262,7 +1262,7 @@ void Smb4KNetworkBrowserPart::slotAddIPAddress( Smb4KHostItem *item )
}
}
- Smb4KNetworkBrowserItem *host_item = static_cast<Smb4KNetworkBrowserItem *>( m_widget->tqfindItem( item->name(), Smb4KNetworkBrowser::Network, ExactMatch|CaseSensitive ) );
+ Smb4KNetworkBrowserItem *host_item = static_cast<Smb4KNetworkBrowserItem *>( m_widget->findItem( item->name(), Smb4KNetworkBrowser::Network, ExactMatch|CaseSensitive ) );
if ( host_item && host_item->tqparent() && TQString::compare( host_item->hostItem()->workgroup(), item->workgroup() ) == 0 )
{
@@ -1287,7 +1287,7 @@ void Smb4KNetworkBrowserPart::slotAddInformation( Smb4KHostItem *item )
{
if ( item )
{
- Smb4KNetworkBrowserItem *browser_item = static_cast<Smb4KNetworkBrowserItem *>( m_widget->tqfindItem( item->name(), Smb4KNetworkBrowser::Network, ExactMatch|CaseSensitive ) );
+ Smb4KNetworkBrowserItem *browser_item = static_cast<Smb4KNetworkBrowserItem *>( m_widget->findItem( item->name(), Smb4KNetworkBrowser::Network, ExactMatch|CaseSensitive ) );
if ( browser_item )
{
@@ -1320,7 +1320,7 @@ void Smb4KNetworkBrowserPart::slotInsertHost( Smb4KHostItem *item )
if ( item )
{
// Look up the workgroup:
- workgroup_item = static_cast<Smb4KNetworkBrowserItem *>( m_widget->tqfindItem( item->workgroup(),
+ workgroup_item = static_cast<Smb4KNetworkBrowserItem *>( m_widget->findItem( item->workgroup(),
Smb4KNetworkBrowser::Network, ExactMatch|CaseSensitive ) );
}
else
diff --git a/smb4k/configdlg/smb4kconfigdialog.cpp b/smb4k/configdlg/smb4kconfigdialog.cpp
index 5e28afc..2c14ded 100644
--- a/smb4k/configdlg/smb4kconfigdialog.cpp
+++ b/smb4k/configdlg/smb4kconfigdialog.cpp
@@ -407,7 +407,7 @@ void Smb4KConfigDialog::saveCustomSambaOptions()
for ( TQValueList<Smb4KSambaOptionsInfo *>::Iterator it = list.begin(); it != list.end(); ++it )
{
- if ( !custom_list->tqfindItem( (*it)->itemName(), Smb4KSambaOptions::ItemName ) )
+ if ( !custom_list->findItem( (*it)->itemName(), Smb4KSambaOptions::ItemName ) )
{
optionsHandler()->removeItem( (*it)->itemName(), false );
@@ -1028,7 +1028,7 @@ void Smb4KConfigDialog::slotCustomSambaSettingsChanged()
it != list.end(); ++it )
{
// Find the item in the list view:
- TQListViewItem *item = view->tqfindItem( (*it)->itemName(), Smb4KSambaOptions::ItemName );
+ TQListViewItem *item = view->findItem( (*it)->itemName(), Smb4KSambaOptions::ItemName );
if ( item )
{
diff --git a/smb4k/core/smb4kcore.cpp b/smb4k/core/smb4kcore.cpp
index a2b5ebf..c176142 100644
--- a/smb4k/core/smb4kcore.cpp
+++ b/smb4k/core/smb4kcore.cpp
@@ -299,17 +299,17 @@ void Smb4KCore::searchPrograms()
// List of paths that should be searched.
TQStringList path_list = TQStringList::split( ":", TQString( "%1" ).tqarg( getenv( "PATH" ) ), false );
- if ( path_list.tqfind( "/sbin" ) == path_list.end() )
+ if ( path_list.find( "/sbin" ) == path_list.end() )
{
path_list << "/sbin";
}
- if ( path_list.tqfind( "/usr/sbin" ) == path_list.end() )
+ if ( path_list.find( "/usr/sbin" ) == path_list.end() )
{
path_list << "/usr/sbin";
}
- if ( path_list.tqfind( "/usr/local/sbin" ) == path_list.end() )
+ if ( path_list.find( "/usr/local/sbin" ) == path_list.end() )
{
path_list << "/usr/local/sbin";
}
diff --git a/smb4k/core/smb4kfileio.cpp b/smb4k/core/smb4kfileio.cpp
index f50db01..64cf608 100644
--- a/smb4k/core/smb4kfileio.cpp
+++ b/smb4k/core/smb4kfileio.cpp
@@ -234,12 +234,12 @@ bool Smb4KFileIO::writeSudoers( Smb4KFileIO::Operation operation )
{
// Find the beginning and the end of the entries in
// the sudoers file:
- TQStringList::Iterator begin = contents.tqfind( "# Entries for Smb4K users." );
- TQStringList::Iterator end = contents.tqfind( "# End of Smb4K user entries." );
+ TQStringList::Iterator begin = contents.find( "# Entries for Smb4K users." );
+ TQStringList::Iterator end = contents.find( "# End of Smb4K user entries." );
for ( TQStringList::Iterator it = begin; it != end; ++it )
{
- if ( (*it).startsWith( "User_Alias\tSMB4KUSERS" ) && (*it).tqcontains( getpwuid( getuid() )->pw_name, true ) == 0 )
+ if ( (*it).startsWith( "User_Alias\tSMB4KUSERS" ) && (*it).contains( getpwuid( getuid() )->pw_name, true ) == 0 )
{
(*it).append( ","+TQString( getpwuid( getuid() )->pw_name ) );
@@ -260,8 +260,8 @@ bool Smb4KFileIO::writeSudoers( Smb4KFileIO::Operation operation )
{
// Find the beginning and the end of the entries in
// the sudoers file:
- TQStringList::Iterator begin = contents.tqfind( "# Entries for Smb4K users." );
- TQStringList::Iterator end = contents.tqfind( "# End of Smb4K user entries." );
+ TQStringList::Iterator begin = contents.find( "# Entries for Smb4K users." );
+ TQStringList::Iterator end = contents.find( "# End of Smb4K user entries." );
// Now, check if the user is in the list of users. If he is,
// remove him from there or remove all if he is the only one:
@@ -271,7 +271,7 @@ bool Smb4KFileIO::writeSudoers( Smb4KFileIO::Operation operation )
{
TQString users = (*it).section( "=", 1, 1 ).stripWhiteSpace();
- if ( users.tqcontains( "," ) == 0 )
+ if ( users.contains( "," ) == 0 )
{
// In this case, there is only one user in the list. Check if
// it is the user who requested the removal:
@@ -298,7 +298,7 @@ bool Smb4KFileIO::writeSudoers( Smb4KFileIO::Operation operation )
TQStringList list = TQStringList::split( ",", users, false );
list.remove( getpwuid( getuid() )->pw_name );
- (*it).tqreplace( users, list.join( "," ) );
+ (*it).replace( users, list.join( "," ) );
write = true;
@@ -587,12 +587,12 @@ bool Smb4KFileIO::writeSuperTab( Smb4KFileIO::Operation operation )
{
// Find the beginning and the end of the entries in
// the super.tab file:
- TQStringList::Iterator begin = contents.tqfind( "# Entries for Smb4K users." );
- TQStringList::Iterator end = contents.tqfind( "# End of Smb4K user entries." );
+ TQStringList::Iterator begin = contents.find( "# Entries for Smb4K users." );
+ TQStringList::Iterator end = contents.find( "# End of Smb4K user entries." );
for ( TQStringList::Iterator it = begin; it != end; ++it )
{
- if ( (*it).startsWith( ":define Smb4KUsers" ) && (*it).tqcontains( getpwuid( getuid() )->pw_name, true ) == 0 )
+ if ( (*it).startsWith( ":define Smb4KUsers" ) && (*it).contains( getpwuid( getuid() )->pw_name, true ) == 0 )
{
(*it).append( ","+TQString( getpwuid( getuid() )->pw_name ) );
@@ -613,8 +613,8 @@ bool Smb4KFileIO::writeSuperTab( Smb4KFileIO::Operation operation )
{
// Find the beginning and the end of the entries in
// the super.tab file:
- TQStringList::Iterator begin = contents.tqfind( "# Entries for Smb4K users." );
- TQStringList::Iterator end = contents.tqfind( "# End of Smb4K user entries." );
+ TQStringList::Iterator begin = contents.find( "# Entries for Smb4K users." );
+ TQStringList::Iterator end = contents.find( "# End of Smb4K user entries." );
// Now, check if the user is in the list of users. If he is,
// remove him from there or remove all if he is the only one:
@@ -624,7 +624,7 @@ bool Smb4KFileIO::writeSuperTab( Smb4KFileIO::Operation operation )
{
TQString users = (*it).section( "Smb4KUsers", 1, 1 ).stripWhiteSpace();
- if ( users.tqcontains( "," ) == 0 )
+ if ( users.contains( "," ) == 0 )
{
// In this case, there is only one user in the list. Check if
// it is the user who requested the removal:
@@ -651,7 +651,7 @@ bool Smb4KFileIO::writeSuperTab( Smb4KFileIO::Operation operation )
TQStringList list = TQStringList::split( ",", users, false );
list.remove( getpwuid( getuid() )->pw_name );
- (*it).tqreplace( users, list.join( "," ) );
+ (*it).replace( users, list.join( "," ) );
write = true;
@@ -1237,12 +1237,12 @@ void Smb4KFileIO::processSudoers()
{
// Find the beginning and the end of the entries in
// the sudoers file:
- TQStringList::Iterator begin = contents.tqfind( "# Entries for Smb4K users." );
- TQStringList::Iterator end = contents.tqfind( "# End of Smb4K user entries." );
+ TQStringList::Iterator begin = contents.find( "# Entries for Smb4K users." );
+ TQStringList::Iterator end = contents.find( "# End of Smb4K user entries." );
for ( TQStringList::Iterator it = begin; it != end; ++it )
{
- if ( (*it).startsWith( "User_Alias\tSMB4KUSERS" ) && (*it).tqcontains( getpwuid( getuid() )->pw_name, true ) == 0 )
+ if ( (*it).startsWith( "User_Alias\tSMB4KUSERS" ) && (*it).contains( getpwuid( getuid() )->pw_name, true ) == 0 )
{
(*it).append( ","+TQString( getpwuid( getuid() )->pw_name ) );
@@ -1263,8 +1263,8 @@ void Smb4KFileIO::processSudoers()
{
// Find the beginning and the end of the entries in
// the sudoers file:
- TQStringList::Iterator begin = contents.tqfind( "# Entries for Smb4K users." );
- TQStringList::Iterator end = contents.tqfind( "# End of Smb4K user entries." );
+ TQStringList::Iterator begin = contents.find( "# Entries for Smb4K users." );
+ TQStringList::Iterator end = contents.find( "# End of Smb4K user entries." );
// Now, check if the user is in the list of users. If he is,
// remove him from there or remove all if he is the only one:
@@ -1274,7 +1274,7 @@ void Smb4KFileIO::processSudoers()
{
TQString users = (*it).section( "=", 1, 1 ).stripWhiteSpace();
- if ( users.tqcontains( "," ) == 0 )
+ if ( users.contains( "," ) == 0 )
{
// In this case, there is only one user in the list. Check if
// it is the user who requested the removal:
@@ -1301,7 +1301,7 @@ void Smb4KFileIO::processSudoers()
TQStringList list = TQStringList::split( ",", users, false );
list.remove( getpwuid( getuid() )->pw_name );
- (*it).tqreplace( users, list.join( "," ) );
+ (*it).replace( users, list.join( "," ) );
write = true;
@@ -1500,12 +1500,12 @@ void Smb4KFileIO::processSuperTab()
{
// Find the beginning and the end of the entries in
// the super.tab file:
- TQStringList::Iterator begin = contents.tqfind( "# Entries for Smb4K users." );
- TQStringList::Iterator end = contents.tqfind( "# End of Smb4K user entries." );
+ TQStringList::Iterator begin = contents.find( "# Entries for Smb4K users." );
+ TQStringList::Iterator end = contents.find( "# End of Smb4K user entries." );
for ( TQStringList::Iterator it = begin; it != end; ++it )
{
- if ( (*it).startsWith( ":define Smb4KUsers" ) && (*it).tqcontains( getpwuid( getuid() )->pw_name, true ) == 0 )
+ if ( (*it).startsWith( ":define Smb4KUsers" ) && (*it).contains( getpwuid( getuid() )->pw_name, true ) == 0 )
{
(*it).append( ","+TQString( getpwuid( getuid() )->pw_name ) );
@@ -1526,8 +1526,8 @@ void Smb4KFileIO::processSuperTab()
{
// Find the beginning and the end of the entries in
// the super.tab file:
- TQStringList::Iterator begin = contents.tqfind( "# Entries for Smb4K users." );
- TQStringList::Iterator end = contents.tqfind( "# End of Smb4K user entries." );
+ TQStringList::Iterator begin = contents.find( "# Entries for Smb4K users." );
+ TQStringList::Iterator end = contents.find( "# End of Smb4K user entries." );
// Now, check if the user is in the list of users. If he is,
// remove him from there or remove all if he is the only one:
@@ -1537,7 +1537,7 @@ void Smb4KFileIO::processSuperTab()
{
TQString users = (*it).section( "Smb4KUsers", 1, 1 ).stripWhiteSpace();
- if ( users.tqcontains( "," ) == 0 )
+ if ( users.contains( "," ) == 0 )
{
// In this case, there is only one user in the list. Check if
// it is the user who requested the removal:
@@ -1564,7 +1564,7 @@ void Smb4KFileIO::processSuperTab()
TQStringList list = TQStringList::split( ",", users, false );
list.remove( getpwuid( getuid() )->pw_name );
- (*it).tqreplace( users, list.join( "," ) );
+ (*it).replace( users, list.join( "," ) );
write = true;
@@ -1708,7 +1708,7 @@ void Smb4KFileIO::slotReceivedStderr( KProcess *, char *buf, int len )
{
TQString error_output = TQString::fromLocal8Bit( buf, len );
- if ( error_output.tqcontains( "smb4k_mv" ) != 0 )
+ if ( error_output.contains( "smb4k_mv" ) != 0 )
{
m_error_occurred = true;
@@ -1721,7 +1721,7 @@ void Smb4KFileIO::slotReceivedStderr( KProcess *, char *buf, int len )
removeLockFile();
}
- else if ( error_output.tqcontains( "smb4k_cat" ) != 0 )
+ else if ( error_output.contains( "smb4k_cat" ) != 0 )
{
m_error_occurred = true;
diff --git a/smb4k/core/smb4kfileio.h b/smb4k/core/smb4kfileio.h
index a11b2e9..496593c 100644
--- a/smb4k/core/smb4kfileio.h
+++ b/smb4k/core/smb4kfileio.h
@@ -82,7 +82,7 @@ class Smb4KFileIO : public TQObject
* @returns TRUE if the write process was successfully initiate and FALSE
* otherwise.
*
- * @note You need to connect to the finished() and failed() signals to tqfind
+ * @note You need to connect to the finished() and failed() signals to find
* out if the the write process finished successfully.
*
*/
@@ -98,7 +98,7 @@ class Smb4KFileIO : public TQObject
* @returns TRUE if the write process was successfully initiate and FALSE
* otherwise.
*
- * @note You need to connect to the finished() and failed() signals to tqfind
+ * @note You need to connect to the finished() and failed() signals to find
* out if the the write process finished successfully.
*
*/
diff --git a/smb4k/core/smb4khomesshareshandler.cpp b/smb4k/core/smb4khomesshareshandler.cpp
index 8aec7fa..35fdb2a 100644
--- a/smb4k/core/smb4khomesshareshandler.cpp
+++ b/smb4k/core/smb4khomesshareshandler.cpp
@@ -134,7 +134,7 @@ const TQString Smb4KHomesSharesHandler::specifyUser( const TQString &host, TQWid
while ( index < userCombo->count() )
{
- if ( list.tqfind( userCombo->text( index ) ) == list.end() )
+ if ( list.find( userCombo->text( index ) ) == list.end() )
{
list.append( userCombo->text( index ) );
}
diff --git a/smb4k/core/smb4kmounter.cpp b/smb4k/core/smb4kmounter.cpp
index 4a419fc..e12b30a 100644
--- a/smb4k/core/smb4kmounter.cpp
+++ b/smb4k/core/smb4kmounter.cpp
@@ -300,16 +300,16 @@ void Smb4KMounter::import()
{
Smb4KShare *new_share = NULL;
- if ( (*it).tqcontains( " smbfs ", false ) != 0 )
+ if ( (*it).contains( " smbfs ", false ) != 0 )
{
TQString share_and_path = (*it).section( " smbfs ", 0, 0 ).stripWhiteSpace();
- TQString name = share_and_path.section( " ", 0, 0 ).stripWhiteSpace().tqreplace( "\\040", "\040" );
+ TQString name = share_and_path.section( " ", 0, 0 ).stripWhiteSpace().replace( "\\040", "\040" );
TQString path = share_and_path.section( " ", 1, 1 ).stripWhiteSpace();
- if ( path.tqcontains( "\\040" ) != 0 || path.tqcontains( "\040" ) != 0 )
+ if ( path.contains( "\\040" ) != 0 || path.contains( "\040" ) != 0 )
{
- name.tqreplace( "_", "\040" );
- path.tqreplace( "\\040", "\040" );
+ name.replace( "_", "\040" );
+ path.replace( "\\040", "\040" );
}
int uid = (*it).section( "uid=", 1, 1 ).section( ",", 0, 0 ).stripWhiteSpace().toInt();
@@ -317,16 +317,16 @@ void Smb4KMounter::import()
new_share = new Smb4KShare( name, path, "smbfs", uid, gid );
}
- else if ( (*it).tqcontains( " cifs ", false ) != 0 )
+ else if ( (*it).contains( " cifs ", false ) != 0 )
{
TQString share_and_path = (*it).section( " cifs ", 0, 0 ).stripWhiteSpace();
- TQString name = share_and_path.section( " ", 0, 0 ).stripWhiteSpace().tqreplace( "\\040", "\040" );
+ TQString name = share_and_path.section( " ", 0, 0 ).stripWhiteSpace().replace( "\\040", "\040" );
TQString path = share_and_path.section( " ", 1, 1 ).stripWhiteSpace();
- if ( path.tqcontains( "\\040" ) != 0 || path.tqcontains( "\040" ) != 0 )
+ if ( path.contains( "\\040" ) != 0 || path.contains( "\040" ) != 0 )
{
- name.tqreplace( "_", "\040" );
- path.tqreplace( "\\040", "\040" );
+ name.replace( "_", "\040" );
+ path.replace( "\\040", "\040" );
}
TQString login = (*it).section( "username=", 1, 1 ).section( ",", 0, 0 ).stripWhiteSpace();
@@ -776,7 +776,7 @@ void Smb4KMounter::unmount( const TQString &mountpoint, bool force, bool noMessa
bool execute = false;
TQString path = mountpoint;
- m_priv->setPath( path.tqreplace( '\044', "\044" ) );
+ m_priv->setPath( path.replace( '\044', "\044" ) );
TQString suid_program, command;
@@ -1032,16 +1032,16 @@ void Smb4KMounter::processMount()
if ( m_proc->normalExit() )
{
- if ( m_buffer.tqcontains( "smb4k_mount:", true ) == 0 &&
- m_buffer.tqcontains( "failed", true ) == 0 &&
- m_buffer.tqcontains( "ERR", true ) == 0 &&
- m_buffer.tqcontains( "/bin/sh:" ) == 0 &&
- m_buffer.tqcontains( "mount:", true ) == 0 &&
- m_buffer.tqcontains( "smbmnt" ) == 0 &&
- m_buffer.tqcontains( m_priv->path() ) == 0 &&
- m_buffer.tqcontains( "mount error" ) == 0 &&
- m_buffer.tqcontains( "bad user name" ) == 0 &&
- m_buffer.tqcontains( "bad group name" ) == 0 )
+ if ( m_buffer.contains( "smb4k_mount:", true ) == 0 &&
+ m_buffer.contains( "failed", true ) == 0 &&
+ m_buffer.contains( "ERR", true ) == 0 &&
+ m_buffer.contains( "/bin/sh:" ) == 0 &&
+ m_buffer.contains( "mount:", true ) == 0 &&
+ m_buffer.contains( "smbmnt" ) == 0 &&
+ m_buffer.contains( m_priv->path() ) == 0 &&
+ m_buffer.contains( "mount error" ) == 0 &&
+ m_buffer.contains( "bad user name" ) == 0 &&
+ m_buffer.contains( "bad group name" ) == 0 )
{
TQString name = TQString( "//%1/%2" ).tqarg( m_priv->host() ).tqarg( m_priv->share() );
@@ -1144,21 +1144,21 @@ void Smb4KMounter::processMount()
}
else
{
- if ( m_buffer.tqcontains( "ERRbadpw" ) != 0 ||
- m_buffer.tqcontains( "ERRnoaccess" ) != 0 ||
- m_buffer.tqcontains( "mount error 13 = Permission denied" ) != 0 )
+ if ( m_buffer.contains( "ERRbadpw" ) != 0 ||
+ m_buffer.contains( "ERRnoaccess" ) != 0 ||
+ m_buffer.contains( "mount error 13 = Permission denied" ) != 0 )
{
int state = Smb4KPasswordHandler::None;
- if ( m_buffer.tqcontains( "ERRbadpw" ) != 0 )
+ if ( m_buffer.contains( "ERRbadpw" ) != 0 )
{
state = Smb4KPasswordHandler::BadPassword;
}
- else if ( m_buffer.tqcontains( "ERRnoaccess" ) != 0 )
+ else if ( m_buffer.contains( "ERRnoaccess" ) != 0 )
{
state = Smb4KPasswordHandler::AccessDenied;
}
- else if ( m_buffer.tqcontains( "mount error 13 = Permission denied" ) != 0 )
+ else if ( m_buffer.contains( "mount error 13 = Permission denied" ) != 0 )
{
state = Smb4KPasswordHandler::PermDenied;
}
@@ -1169,9 +1169,9 @@ void Smb4KMounter::processMount()
mountShare( m_priv->workgroup(), m_priv->host(), m_priv->ip(), m_priv->share() );
}
}
- else if ( m_buffer.tqcontains( "ERRnosuchshare" ) != 0 && m_priv->share().tqcontains( "_" ) != 0 )
+ else if ( m_buffer.contains( "ERRnosuchshare" ) != 0 && m_priv->share().contains( "_" ) != 0 )
{
- TQString share_string = static_cast<TQString>( m_priv->share() ).tqreplace( "_", " " );
+ TQString share_string = static_cast<TQString>( m_priv->share() ).replace( "_", " " );
mountShare( m_priv->workgroup(), m_priv->host(), m_priv->ip(), share_string );
}
else
@@ -1187,13 +1187,13 @@ void Smb4KMounter::processMount()
if ( m_proc->normalExit() )
{
- if ( m_buffer.tqcontains( "smb4k_mount:", true ) == 0 &&
- m_buffer.tqcontains( "syserr =", true ) == 0 &&
+ if ( m_buffer.contains( "smb4k_mount:", true ) == 0 &&
+ m_buffer.contains( "syserr =", true ) == 0 &&
/* To make sure we catch all errors, also check for the following
strings. Maybe we can remove them?? */
- m_buffer.tqcontains( "Authentication error", true ) == 0 &&
- m_buffer.tqcontains( "Connection refused", true ) == 0 &&
- m_buffer.tqcontains( "Operation not permitted", true ) == 0 )
+ m_buffer.contains( "Authentication error", true ) == 0 &&
+ m_buffer.contains( "Connection refused", true ) == 0 &&
+ m_buffer.contains( "Operation not permitted", true ) == 0 )
{
import(); // FIXME: *cough* What is this for???
@@ -1212,7 +1212,7 @@ void Smb4KMounter::processMount()
}
else
{
- if ( m_buffer.tqcontains( "Authentication error" ) != 0 )
+ if ( m_buffer.contains( "Authentication error" ) != 0 )
{
// If the user supplied auth information, we will retry mounting.
if ( passwordHandler()->askpass( m_priv->workgroup(), m_priv->host(), m_priv->share(), Smb4KPasswordHandler::AuthError ) )
@@ -1272,7 +1272,7 @@ void Smb4KMounter::processUnmount()
// rare circumstances it might occur that sudo reports an error,
// because it is not able to resolve the host. This error message
// will be removed, because it does not affect the unmounting:
- if ( m_buffer.tqcontains( "sudo: unable to resolve host", true ) != 0 )
+ if ( m_buffer.contains( "sudo: unable to resolve host", true ) != 0 )
{
size_t hostnamelen = 255;
char *hostname = new char[hostnamelen];
@@ -1405,7 +1405,7 @@ TQValueList<Smb4KShare> Smb4KMounter::findShareByName( const TQString &name )
for ( TQValueListIterator<Smb4KShare *> it = m_mounted_shares.begin(); it != m_mounted_shares.end(); ++it )
{
if( TQString::compare( (*it)->name().upper(), name.upper() ) == 0 ||
- TQString::compare( (*it)->name().upper(), n.tqreplace( " ", "_" ).upper() ) == 0 )
+ TQString::compare( (*it)->name().upper(), n.replace( " ", "_" ).upper() ) == 0 )
{
list.append( *(*it) );
diff --git a/smb4k/core/smb4kpasswordhandler.cpp b/smb4k/core/smb4kpasswordhandler.cpp
index fcda266..2b7e6ff 100644
--- a/smb4k/core/smb4kpasswordhandler.cpp
+++ b/smb4k/core/smb4kpasswordhandler.cpp
@@ -172,7 +172,7 @@ void Smb4KPasswordHandler::convert_old_entries()
// this: HOST:USER, we only need to test whether the first
// key contains a ":". If that's the case, we need to convert
// the entries, otherwise we don't.
- if ( entries.first().tqcontains( ":" ) != 0 )
+ if ( entries.first().contains( ":" ) != 0 )
{
for ( TQStringList::Iterator it = entries.begin(); it != entries.end(); ++it )
{
@@ -450,7 +450,7 @@ Smb4KAuthInfo *Smb4KPasswordHandler::readAuth( Smb4KAuthInfo *authInfo )
else
{
// Check that the workgroup is correct.
- if ( map.tqcontains( "Workgroup" ) && !authInfo->workgroup().isEmpty() )
+ if ( map.contains( "Workgroup" ) && !authInfo->workgroup().isEmpty() )
{
if ( TQString::compare( map["Workgroup"].upper(), authInfo->workgroup().upper() ) != 0 )
{
@@ -473,7 +473,7 @@ Smb4KAuthInfo *Smb4KPasswordHandler::readAuth( Smb4KAuthInfo *authInfo )
else
{
// Check that the workgroup is correct.
- if ( map.tqcontains( "Workgroup" ) && !authInfo->workgroup().isEmpty() )
+ if ( map.contains( "Workgroup" ) && !authInfo->workgroup().isEmpty() )
{
if ( TQString::compare( map["Workgroup"].upper(), authInfo->workgroup().upper() ) != 0 )
{
@@ -516,7 +516,7 @@ Smb4KAuthInfo *Smb4KPasswordHandler::readAuth( Smb4KAuthInfo *authInfo )
else
{
// Check that the workgroup is correct.
- if ( map.tqcontains( "Workgroup" ) && !authInfo->workgroup().isEmpty() )
+ if ( map.contains( "Workgroup" ) && !authInfo->workgroup().isEmpty() )
{
if ( TQString::compare( map["Workgroup"].upper(), authInfo->workgroup().upper() ) != 0 )
{
@@ -874,8 +874,8 @@ void Smb4KPasswordHandler::slotWritePassword( KProcess *proc )
}
// Check if the [default] section is present.
- if ( contents.tqfind( "[default]" ) == contents.end() &&
- contents.tqfind( "[DEFAULT]" ) == contents.end() )
+ if ( contents.find( "[default]" ) == contents.end() &&
+ contents.find( "[DEFAULT]" ) == contents.end() )
{
TQMap<TQString,TQString> map = m_options_handler->globalSambaOptions();
TQString workgroup = map["workgroup"];
@@ -908,7 +908,7 @@ void Smb4KPasswordHandler::slotWritePassword( KProcess *proc )
section.append( TQString( "[%1:%2:%3]" ).tqarg( m_nsmbrc_auth.host().upper(), m_nsmbrc_auth.user().isEmpty() ? "GUEST" : m_nsmbrc_auth.user().upper(), m_nsmbrc_auth.share().upper() ) );
}
- TQStringList::Iterator it = contents.tqfind( section );
+ TQStringList::Iterator it = contents.find( section );
if ( it == contents.end() )
{
@@ -929,7 +929,7 @@ void Smb4KPasswordHandler::slotWritePassword( KProcess *proc )
{
for ( TQStringList::Iterator i = ++it; i != contents.end(); ++i )
{
- if ( (*i).tqcontains( "password=" ) )
+ if ( (*i).contains( "password=" ) )
{
TQString old_pass = (*i).section( "password=", 1, 1 ).stripWhiteSpace();
diff --git a/smb4k/core/smb4kpreviewer.cpp b/smb4k/core/smb4kpreviewer.cpp
index 52ebbab..6d76f8f 100644
--- a/smb4k/core/smb4kpreviewer.cpp
+++ b/smb4k/core/smb4kpreviewer.cpp
@@ -215,7 +215,7 @@ void Smb4KPreviewer::slotProcessExited( KProcess * )
TQString error_code = list.grep( "NT_STATUS" ).first().stripWhiteSpace().section( " ", 0, 0 );
// The error output of smbclient is a little bit inconsistent:
- if ( error_code.tqcontains( "NT_STATUS" ) == 0 )
+ if ( error_code.contains( "NT_STATUS" ) == 0 )
{
error_code = list.grep( "NT_STATUS" ).first().stripWhiteSpace().section( " ", -1, -1 );
}
@@ -287,7 +287,7 @@ void Smb4KPreviewer::slotProcessExited( KProcess * )
{
continue;
}
- else if ( (*it).tqcontains( "blocks of size" ) != 0 )
+ else if ( (*it).contains( "blocks of size" ) != 0 )
{
continue;
}
@@ -297,7 +297,7 @@ void Smb4KPreviewer::slotProcessExited( KProcess * )
TQString item = tmp.section( " ", 0, -2 ).stripWhiteSpace();
- if ( !item.isEmpty() && tmp.section( " ", -1, -1 ).tqcontains( "D" ) != 0 )
+ if ( !item.isEmpty() && tmp.section( " ", -1, -1 ).contains( "D" ) != 0 )
{
// We have a directory here.
if ( item.startsWith( "." ) &&
@@ -313,7 +313,7 @@ void Smb4KPreviewer::slotProcessExited( KProcess * )
continue;
}
- else if ( item.isEmpty() || tmp.section( " ", -1, -1 ).tqcontains( "D" ) == 0 )
+ else if ( item.isEmpty() || tmp.section( " ", -1, -1 ).contains( "D" ) == 0 )
{
// We have a file
if ( item.isEmpty() )
diff --git a/smb4k/core/smb4kprint.cpp b/smb4k/core/smb4kprint.cpp
index d666ed5..76e4a9a 100644
--- a/smb4k/core/smb4kprint.cpp
+++ b/smb4k/core/smb4kprint.cpp
@@ -302,7 +302,7 @@ void Smb4KPrint::slotReceivedStderr( KProcess *, char *buf, int len )
{
m_buffer.append( TQString::fromLocal8Bit( buf, len ) );
- if ( m_buffer.tqcontains( "NT_STATUS" ) != 0 )
+ if ( m_buffer.contains( "NT_STATUS" ) != 0 )
{
abort();
}
@@ -313,19 +313,19 @@ void Smb4KPrint::slotProcessExited( KProcess * )
{
bool retry = false;
- if ( m_buffer.tqcontains( "NT_STATUS", true ) != 0 ||
- m_buffer.tqcontains( "enscript", true ) != 0 ||
- m_buffer.tqcontains( "dvips", true ) != 0 )
+ if ( m_buffer.contains( "NT_STATUS", true ) != 0 ||
+ m_buffer.contains( "enscript", true ) != 0 ||
+ m_buffer.contains( "dvips", true ) != 0 )
{
- if ( m_buffer.tqcontains( "NT_STATUS_ACCESS_DENIED" ) != 0 || m_buffer.tqcontains( "NT_STATUS_LOGON_FAILURE" ) != 0 )
+ if ( m_buffer.contains( "NT_STATUS_ACCESS_DENIED" ) != 0 || m_buffer.contains( "NT_STATUS_LOGON_FAILURE" ) != 0 )
{
int state = Smb4KPasswordHandler::None;
- if ( m_buffer.tqcontains( "NT_STATUS_ACCESS_DENIED" ) != 0 )
+ if ( m_buffer.contains( "NT_STATUS_ACCESS_DENIED" ) != 0 )
{
state = Smb4KPasswordHandler::AccessDenied;
}
- else if (m_buffer.tqcontains( "NT_STATUS_LOGON_FAILURE" ) != 0 )
+ else if (m_buffer.contains( "NT_STATUS_LOGON_FAILURE" ) != 0 )
{
state = Smb4KPasswordHandler::LogonFailure;
}
diff --git a/smb4k/core/smb4ksambaoptionshandler.cpp b/smb4k/core/smb4ksambaoptionshandler.cpp
index 5a2facd..acd2d82 100644
--- a/smb4k/core/smb4ksambaoptionshandler.cpp
+++ b/smb4k/core/smb4ksambaoptionshandler.cpp
@@ -1389,7 +1389,7 @@ void Smb4KSambaOptionsHandler::read_smb_conf()
}
// Process the file contents.
- for ( TQStringList::Iterator it = contents.erase( contents.begin(), ++(contents.tqfind( "[global]" )) ); it != contents.end(); ++it )
+ for ( TQStringList::Iterator it = contents.erase( contents.begin(), ++(contents.find( "[global]" )) ); it != contents.end(); ++it )
{
if ( (*it).stripWhiteSpace().startsWith( "#" ) || (*it).stripWhiteSpace().startsWith( ";" ) )
{
@@ -1456,7 +1456,7 @@ void Smb4KSambaOptionsHandler::read_smb_conf()
// Post-processing. Some values should be entered with their defaults, if they are
// not already present.
- if ( !m_samba_options.tqcontains( "netbios name" ) )
+ if ( !m_samba_options.contains( "netbios name" ) )
{
size_t hostnamelen = 255;
char *hostname = new char[hostnamelen];
diff --git a/smb4k/core/smb4ksambaoptionsinfo.cpp b/smb4k/core/smb4ksambaoptionsinfo.cpp
index c9e7990..995796d 100644
--- a/smb4k/core/smb4ksambaoptionsinfo.cpp
+++ b/smb4k/core/smb4ksambaoptionsinfo.cpp
@@ -107,7 +107,7 @@ void Smb4KSambaOptionsInfo::setKerberos( bool krb )
int Smb4KSambaOptionsInfo::type()
{
- return m_name.tqcontains( "/" ) == 3 ? Share : Host;
+ return m_name.contains( "/" ) == 3 ? Share : Host;
}
diff --git a/smb4k/core/smb4ksynchronizationinfo.h b/smb4k/core/smb4ksynchronizationinfo.h
index 72f2ad9..e8688ce 100644
--- a/smb4k/core/smb4ksynchronizationinfo.h
+++ b/smb4k/core/smb4ksynchronizationinfo.h
@@ -124,7 +124,7 @@ class Smb4KSynchronizationInfo
const int processedFileNumber() const { return m_processed_files; }
/**
- * Set the transfer rate. This should be a string that already tqcontains
+ * Set the transfer rate. This should be a string that already contains
* all information, i.e. the string should look like this: 100 kB/s.
*
* @param rate The rate string (e.g. 100 kB/s)
diff --git a/smb4k/core/smb4ksynchronizer.cpp b/smb4k/core/smb4ksynchronizer.cpp
index 8333e0f..8944157 100644
--- a/smb4k/core/smb4ksynchronizer.cpp
+++ b/smb4k/core/smb4ksynchronizer.cpp
@@ -389,7 +389,7 @@ void Smb4KSynchronizer::slotReceivedStdout( KProcess *, char *buf, int len )
TQString partial, total, files, rate;
- if ( m_buffer[0].isSpace() && m_buffer.tqcontains( "/s ", true ) > 0 )
+ if ( m_buffer[0].isSpace() && m_buffer.contains( "/s ", true ) > 0 )
{
partial = m_buffer.section( "%", 0, 0 ).section( " ", -1, -1 ).stripWhiteSpace();
@@ -398,7 +398,7 @@ void Smb4KSynchronizer::slotReceivedStdout( KProcess *, char *buf, int len )
sync_info.setIndividualProgress( partial.toInt() );
}
- if ( m_buffer.tqcontains( "to-check=" ) > 0 )
+ if ( m_buffer.contains( "to-check=" ) > 0 )
{
// Newer versions of rsync:
TQString tmp = m_buffer.section( "to-check=", 1, 1 ).section( ")", 0, 0 ).stripWhiteSpace();
@@ -423,7 +423,7 @@ void Smb4KSynchronizer::slotReceivedStdout( KProcess *, char *buf, int len )
sync_info.setTotalProgress( total.toInt() );
}
- if ( m_buffer.tqcontains( "xfer#" ) > 0 )
+ if ( m_buffer.contains( "xfer#" ) > 0 )
{
// Newer versions of rsync:
files = m_buffer.section( "xfer#", 1, 1 ).section( ",", 0, 0 ).stripWhiteSpace();
@@ -452,11 +452,11 @@ void Smb4KSynchronizer::slotReceivedStdout( KProcess *, char *buf, int len )
m_buffer = TQString();
}
- else if ( !m_buffer[0].isSpace() && m_buffer.endsWith( "\n" ) && m_buffer.tqcontains( "/s ", true ) == 0 )
+ else if ( !m_buffer[0].isSpace() && m_buffer.endsWith( "\n" ) && m_buffer.contains( "/s ", true ) == 0 )
{
sync_info.setText( m_buffer.stripWhiteSpace() );
- if ( m_buffer.tqcontains( "files to consider" ) != 0 )
+ if ( m_buffer.contains( "files to consider" ) != 0 )
{
m_total_files = m_buffer.section( " files to consider", 0, 0 ).section( " ", -1, -1 ).stripWhiteSpace();
@@ -479,7 +479,7 @@ void Smb4KSynchronizer::slotReceivedStderr( KProcess *, char *buf, int len )
// when you kill the process (using SIGTERM). Pressing the cancel
// button will exactly do this. Thus, we need to exclude this occasion
// from here.
- if ( !cancel && error_message.tqcontains( "rsync error:", true ) != 0 )
+ if ( !cancel && error_message.contains( "rsync error:", true ) != 0 )
{
// Cancel the whole synchronization in case an error occurred.
// If we don't do it, the user might be flooded with error messages
diff --git a/smb4k/dialogs/smb4kmountdialog.cpp b/smb4k/dialogs/smb4kmountdialog.cpp
index 6e7d7c4..4cf33a2 100644
--- a/smb4k/dialogs/smb4kmountdialog.cpp
+++ b/smb4k/dialogs/smb4kmountdialog.cpp
@@ -115,10 +115,10 @@ void Smb4KMountDialog::slotOk()
if ( !m_share_input->text().stripWhiteSpace().isEmpty() )
{
#ifndef __FreeBSD__
- if ( m_share_input->text().tqcontains( "/" ) == 3 )
+ if ( m_share_input->text().contains( "/" ) == 3 )
#else
- if ( m_share_input->text().tqcontains( "/" ) == 3
- && m_share_input->text().tqcontains( '@' ) == 0 )
+ if ( m_share_input->text().contains( "/" ) == 3
+ && m_share_input->text().contains( '@' ) == 0 )
#endif
{
TQString host = m_share_input->text().stripWhiteSpace().section( "/", 2, 2 );
diff --git a/smb4k/dialogs/smb4kpreviewdialog.cpp b/smb4k/dialogs/smb4kpreviewdialog.cpp
index 6c06919..0b7c280 100644
--- a/smb4k/dialogs/smb4kpreviewdialog.cpp
+++ b/smb4k/dialogs/smb4kpreviewdialog.cpp
@@ -172,7 +172,7 @@ void Smb4KPreviewDialog::slotReceivedData( Smb4KPreviewItem *item )
for ( TQStringList::Iterator it = m_history.begin(); it != m_history.end(); it++ )
{
- if ( !m_combo->listBox()->tqfindItem( *it, TQt::CaseSensitive|TQt::ExactMatch ) )
+ if ( !m_combo->listBox()->findItem( *it, TQt::CaseSensitive|TQt::ExactMatch ) )
{
m_combo->insertItem( *it, -1 );
}
@@ -285,11 +285,11 @@ void Smb4KPreviewDialog::slotButtonClicked( int id )
return;
}
- if ( m_item->path().tqcontains( "/" ) > 1 )
+ if ( m_item->path().contains( "/" ) > 1 )
{
m_item->setPath( m_item->path().section( "/", 0, -3 ).append( "/" ) );
}
- else if ( m_item->path().tqcontains( "/", true ) == 1 )
+ else if ( m_item->path().contains( "/", true ) == 1 )
{
m_item->setPath( TQString() );
}
@@ -311,7 +311,7 @@ void Smb4KPreviewDialog::slotButtonClicked( int id )
}
// Get the path:
- if ( (*m_current_item).tqcontains( "/", true ) == 3 )
+ if ( (*m_current_item).contains( "/", true ) == 3 )
{
m_item->setPath( TQString() );
}
@@ -346,7 +346,7 @@ void Smb4KPreviewDialog::slotButtonClicked( int id )
}
// Get the path:
- if ( (*m_current_item).tqcontains( "/", true ) == 3 )
+ if ( (*m_current_item).contains( "/", true ) == 3 )
{
m_item->setPath( TQString() );
}
diff --git a/smb4k/iconview/smb4ksharesiconview.cpp b/smb4k/iconview/smb4ksharesiconview.cpp
index 197484d..b7dfb7e 100644
--- a/smb4k/iconview/smb4ksharesiconview.cpp
+++ b/smb4k/iconview/smb4ksharesiconview.cpp
@@ -120,7 +120,7 @@ void Smb4KSharesIconView::contentsDragEnterEvent( TQDragEnterEvent *e )
void Smb4KSharesIconView::contentsDragMoveEvent( TQDragMoveEvent *e )
{
- TQIconViewItem *item = tqfindItem( e->pos() );
+ TQIconViewItem *item = findItem( e->pos() );
e->accept( Smb4KSettings::enableDropSupport() && item );
}
@@ -128,7 +128,7 @@ void Smb4KSharesIconView::contentsDragMoveEvent( TQDragMoveEvent *e )
void Smb4KSharesIconView::contentsDropEvent( TQDropEvent *e )
{
- TQIconViewItem *item = tqfindItem( e->pos() );
+ TQIconViewItem *item = findItem( e->pos() );
KURL::List src;
// Do we have to stop here?
@@ -172,7 +172,7 @@ void Smb4KSharesIconView::contentsMouseMoveEvent( TQMouseEvent *e )
{
m_pos = e->globalPos();
- Smb4KSharesIconViewItem *item = static_cast<Smb4KSharesIconViewItem *>( tqfindItem( e->pos() ) );
+ Smb4KSharesIconViewItem *item = static_cast<Smb4KSharesIconViewItem *>( findItem( e->pos() ) );
if ( item )
{
@@ -256,7 +256,7 @@ void Smb4KSharesIconView::slotPressed( TQIconViewItem *item )
void Smb4KSharesIconView::slotShowToolTip()
{
if ( m_tooltip && hasMouse() && Smb4KSettings::showShareToolTip() &&
- (m_tooltip->item() == static_cast<Smb4KSharesIconViewItem *>( tqfindItem( viewport()->mapFromGlobal( m_pos ) ) )) )
+ (m_tooltip->item() == static_cast<Smb4KSharesIconViewItem *>( findItem( viewport()->mapFromGlobal( m_pos ) ) )) )
{
m_tooltip->showTip( m_pos );
}
diff --git a/smb4k/main.cpp b/smb4k/main.cpp
index 7ebaa97..439e5be 100644
--- a/smb4k/main.cpp
+++ b/smb4k/main.cpp
@@ -119,12 +119,12 @@ int main( int argc, char *argv[] )
KConfig config( "smb4krc", false, false, "config" );
if ( !config.groupList().isEmpty() &&
- (config.groupList().tqcontains( "Browse Options" ) != 0 ||
- config.groupList().tqcontains( "Mount Options" ) != 0 ||
- config.groupList().tqcontains( "Rsync" ) != 0 ||
- config.groupList().tqcontains( "Super User Privileges") != 0 ||
- config.groupList().tqcontains( "User Interface" ) != 0 ||
- config.groupList().tqcontains( "System" ) != 0) )
+ (config.groupList().contains( "Browse Options" ) != 0 ||
+ config.groupList().contains( "Mount Options" ) != 0 ||
+ config.groupList().contains( "Rsync" ) != 0 ||
+ config.groupList().contains( "Super User Privileges") != 0 ||
+ config.groupList().contains( "User Interface" ) != 0 ||
+ config.groupList().contains( "System" ) != 0) )
{
int return_value = KMessageBox::warningContinueCancel( 0, i18n( "Smb4K now uses a different configuration system. Thus, your old settings are obsolete and you have to reconfigure the application.\nTo assure a clean transition, the current configuration file will be removed." ) );
diff --git a/smb4k/searchdlg/smb4ksearchdialog.cpp b/smb4k/searchdlg/smb4ksearchdialog.cpp
index 0feda21..e092958 100644
--- a/smb4k/searchdlg/smb4ksearchdialog.cpp
+++ b/smb4k/searchdlg/smb4ksearchdialog.cpp
@@ -54,7 +54,7 @@ Smb4KSearchDialog::Smb4KSearchDialog( TQWidget *tqparent, const char *name )
m_tool_bar->insertSeparator();
- m_tool_bar->insertButton( "tqfind", Search, false, i18n( "Search" ) );
+ m_tool_bar->insertButton( "find", Search, false, i18n( "Search" ) );
m_tool_bar->insertButton( "editdelete", Clear, false, i18n( "Clear" ) );
m_tool_bar->insertButton( "button_ok", Add, false, i18n( "Add" ) );
diff --git a/smb4k/smb4k.cpp b/smb4k/smb4k.cpp
index 8021c8b..8281ed9 100644
--- a/smb4k/smb4k.cpp
+++ b/smb4k/smb4k.cpp
@@ -313,7 +313,7 @@ void Smb4KApp::setupView()
if ( m_search_part )
{
- KDockWidget *search = createDockWidget( "SearchDialog", SmallIcon( "tqfind" ), 0L, i18n( "Search Dialog" ) );
+ KDockWidget *search = createDockWidget( "SearchDialog", SmallIcon( "find" ), 0L, i18n( "Search Dialog" ) );
search->setWidget( m_search_part->widget() );
KDockWidget *network = manager()->getDockWidgetFromName( "NetworkBrowser" );
diff --git a/smb4k/smb4ksystemtray.cpp b/smb4k/smb4ksystemtray.cpp
index 4b25391..d383a74 100644
--- a/smb4k/smb4ksystemtray.cpp
+++ b/smb4k/smb4ksystemtray.cpp
@@ -828,11 +828,11 @@ void Smb4KSystemTray::slotSetupSharesMenu()
{
TQString item = TQString( "%1_::_%2" ).tqarg( TQString((*it)->name()), TQString((*it)->canonicalPath()) );
- index = strings.tqfindIndex( item );
+ index = strings.findIndex( item );
}
else
{
- index = strings.tqfindIndex( (*it)->canonicalPath() );
+ index = strings.findIndex( (*it)->canonicalPath() );
}
m_shares_menu->insert( action_menu, index + 2 ); // +2 due to "Unmount All" and separator
diff --git a/utilities/smb4k_kill.cpp b/utilities/smb4k_kill.cpp
index 546a4bb..7c31bfd 100644
--- a/utilities/smb4k_kill.cpp
+++ b/utilities/smb4k_kill.cpp
@@ -82,7 +82,7 @@ bool find_program( const char *name, char *path )
if ( !strcmp( file.c_str(), "" ) )
{
- cerr << "smb4k_kill: Could not tqfind " << name << " binary" << endl;
+ cerr << "smb4k_kill: Could not find " << name << " binary" << endl;
return false;
}
diff --git a/utilities/smb4k_mount.cpp b/utilities/smb4k_mount.cpp
index 2ae1318..2e82f28 100644
--- a/utilities/smb4k_mount.cpp
+++ b/utilities/smb4k_mount.cpp
@@ -109,7 +109,7 @@ bool find_program( const char *name, char *path )
if ( !strcmp( file.c_str(), "" ) )
{
- cerr << "smb4k_mount: Could not tqfind " << name << " binary" << endl;
+ cerr << "smb4k_mount: Could not find " << name << " binary" << endl;
return false;
}
diff --git a/utilities/smb4k_mv.cpp b/utilities/smb4k_mv.cpp
index 119916f..7949722 100644
--- a/utilities/smb4k_mv.cpp
+++ b/utilities/smb4k_mv.cpp
@@ -93,7 +93,7 @@ bool find_program( const char *name, char *path )
if ( !strcmp( file.c_str(), "" ) )
{
- cerr << "smb4k_mv: Could not tqfind " << name << " binary" << endl;
+ cerr << "smb4k_mv: Could not find " << name << " binary" << endl;
return false;
}
diff --git a/utilities/smb4k_umount.cpp b/utilities/smb4k_umount.cpp
index fb82039..23eb266 100644
--- a/utilities/smb4k_umount.cpp
+++ b/utilities/smb4k_umount.cpp
@@ -121,7 +121,7 @@ bool find_program( const char *name, char *path )
if ( !strcmp( file.c_str(), "" ) )
{
- cerr << "smb4k_umount: Could not tqfind " << name << " binary" << endl;
+ cerr << "smb4k_umount: Could not find " << name << " binary" << endl;
return false;
}
diff --git a/smb4k/core/smb4kscanner.cpp b/smb4k/core/smb4kscanner.cpp
index b4da920..f9d3021 100644
--- a/smb4k/core/smb4kscanner.cpp
+++ b/smb4k/core/smb4kscanner.cpp
@@ -247,7 +247,7 @@ void Smb4KScanner::scanNetwork()
// Look up the workgroups/domains and their master browsers.
// At the moment we have three methods:
// (1) Smb4KSettings::EnumBrowseList::LookupDomains: This method is
- // the most reliable one. It uses nmblookup and will only tqfind
+ // the most reliable one. It uses nmblookup and will only find
// *active* workgroup master browsers and thus active domains.
// (2) Smb4KSettings::EnumBrowseList::QueryCurrentMaster: This
// method will query the current master browser of the local
@@ -546,7 +546,7 @@ void Smb4KScanner::searchForHost( const TQString &host )
command.append( nmblookup_options );
}
- if ( host.tqcontains( '.', true ) != 3 )
+ if ( host.contains( '.', true ) != 3 )
{
if ( !wins.isEmpty() )
{
@@ -691,7 +691,7 @@ void Smb4KScanner::processWorkgroups()
continue;
}
- else if ( (*it).tqcontains( "<00>" ) != 0 && (*it).tqcontains( "<GROUP>" ) == 0 )
+ else if ( (*it).contains( "<00>" ) != 0 && (*it).contains( "<GROUP>" ) == 0 )
{
if ( workgroup.isEmpty() && master.isEmpty() && !ip.isEmpty() )
{
@@ -700,11 +700,11 @@ void Smb4KScanner::processWorkgroups()
continue;
}
- else if ( (*it).tqcontains( "<00>" ) != 0 && (*it).tqcontains( "<GROUP>" ) != 0 )
+ else if ( (*it).contains( "<00>" ) != 0 && (*it).contains( "<GROUP>" ) != 0 )
{
if ( workgroup.isEmpty() && !master.isEmpty() && !ip.isEmpty() )
{
- workgroup = (*it).left( (*it).tqfind( "<00>" ) ).stripWhiteSpace();
+ workgroup = (*it).left( (*it).find( "<00>" ) ).stripWhiteSpace();
m_workgroups_list->append( new Smb4KWorkgroupItem( workgroup, master, ip ) );
@@ -800,9 +800,9 @@ void Smb4KScanner::processIPScan()
// Loop through the data:
for ( TQStringList::ConstIterator i = it; i != list.end(); ++i )
{
- if ( (*i).tqcontains( " <00> " ) != 0 )
+ if ( (*i).contains( " <00> " ) != 0 )
{
- if ( (*i).tqcontains( " <GROUP> " ) != 0 )
+ if ( (*i).contains( " <GROUP> " ) != 0 )
{
workgroup = (*i).section( "<00>", 0, 0 ).stripWhiteSpace();
}
@@ -813,13 +813,13 @@ void Smb4KScanner::processIPScan()
continue;
}
- else if ( (*i).tqcontains( "__MSBROWSE__" ) != 0 && (*i).tqcontains( " <01> " ) != 0 )
+ else if ( (*i).contains( "__MSBROWSE__" ) != 0 && (*i).contains( " <01> " ) != 0 )
{
master = true;
continue;
}
- else if ( (*i).tqcontains( "MAC Address" ) != 0 || (*i).stripWhiteSpace().isEmpty() )
+ else if ( (*i).contains( "MAC Address" ) != 0 || (*i).stripWhiteSpace().isEmpty() )
{
it = i;
@@ -897,9 +897,9 @@ void Smb4KScanner::processWorkgroupMembers()
case Smb4KSettings::EnumBrowseList::QueryCurrentMaster:
case Smb4KSettings::EnumBrowseList::QueryCustomMaster:
{
- if ( m_buffer.tqcontains( "NT_STATUS_ACCESS_DENIED" ) != 0 ||
- m_buffer.tqcontains( "NT_STATUS_LOGON_FAILURE" ) != 0 ||
- m_buffer.tqcontains( "The username or password was not correct" ) != 0 )
+ if ( m_buffer.contains( "NT_STATUS_ACCESS_DENIED" ) != 0 ||
+ m_buffer.contains( "NT_STATUS_LOGON_FAILURE" ) != 0 ||
+ m_buffer.contains( "The username or password was not correct" ) != 0 )
{
// Authentication failed:
emit failed();
@@ -913,11 +913,11 @@ void Smb4KScanner::processWorkgroupMembers()
return;
}
- else if ( m_buffer.tqcontains( "Could not connect to server" ) != 0 ||
- m_buffer.tqcontains( "Unable to find a suitable server" ) != 0 ||
- m_buffer.tqcontains( "Invalid ip address specified" ) != 0 )
+ else if ( m_buffer.contains( "Could not connect to server" ) != 0 ||
+ m_buffer.contains( "Unable to find a suitable server" ) != 0 ||
+ m_buffer.contains( "Invalid ip address specified" ) != 0 )
{
// If the IP address is empty, the shell output tqcontains
// the IP address. Remove it, because it will confuse
// the user:
if ( m_priv->ip().isEmpty() )
@@ -974,7 +974,7 @@ void Smb4KScanner::processWorkgroupMembers()
{
TQString host, comment;
- if ( line.tqcontains( " " ) == 0 )
+ if ( line.contains( " " ) == 0 )
{
host = line;
}
@@ -1079,9 +1079,9 @@ void Smb4KScanner::processWorkgroupMembers()
}
case Smb4KSettings::EnumBrowseList::ScanBroadcastAreas:
{
- if ( m_buffer.tqcontains( "NT_STATUS_ACCESS_DENIED" ) != 0 ||
- m_buffer.tqcontains( "NT_STATUS_LOGON_FAILURE" ) != 0 ||
- m_buffer.tqcontains( "The username or password was not correct" ) != 0 )
+ if ( m_buffer.contains( "NT_STATUS_ACCESS_DENIED" ) != 0 ||
+ m_buffer.contains( "NT_STATUS_LOGON_FAILURE" ) != 0 ||
+ m_buffer.contains( "The username or password was not correct" ) != 0 )
{
// Authentication failed:
emit failed();
@@ -1095,9 +1095,9 @@ void Smb4KScanner::processWorkgroupMembers()
return;
}
- else if ( m_buffer.tqcontains( "Could not connect to server" ) != 0 ||
- m_buffer.tqcontains( "Unable to find a suitable server" ) != 0 ||
- m_buffer.tqcontains( "Invalid ip address specified" ) != 0 )
+ else if ( m_buffer.contains( "Could not connect to server" ) != 0 ||
+ m_buffer.contains( "Unable to find a suitable server" ) != 0 ||
+ m_buffer.contains( "Invalid ip address specified" ) != 0 )
{
// We are in IP scan mode, so we can ignore the error and emit
// what we already have:
@@ -1128,7 +1128,7 @@ void Smb4KScanner::processWorkgroupMembers()
// Extract host name and comment:
TQString host, comment;
- if ( line.tqcontains( " " ) == 0 )
+ if ( line.contains( " " ) == 0 )
{
host = line;
}
@@ -1179,8 +1179,8 @@ void Smb4KScanner::processWorkgroupMembers()
void Smb4KScanner::processShares()
{
// Error handling
- if ( m_buffer.tqcontains( "The username or password was not correct.", true ) != 0 ||
- m_buffer.tqcontains( "NT_STATUS_ACCOUNT_DISABLED" ) != 0 /* Active Directory error */ )
+ if ( m_buffer.contains( "The username or password was not correct.", true ) != 0 ||
+ m_buffer.contains( "NT_STATUS_ACCOUNT_DISABLED" ) != 0 /* Active Directory error */ )
{
// Authentication failed:
emit failed();
@@ -1192,7 +1192,7 @@ void Smb4KScanner::processShares()
return;
}
- else if ( m_buffer.tqcontains( "could not obtain sid for domain", true ) != 0 )
+ else if ( m_buffer.contains( "could not obtain sid for domain", true ) != 0 )
{
// FIXME: Does this error only occur when we scan a server that is
// only capable of the RAP protocol or also under other conditions?
@@ -1202,9 +1202,9 @@ void Smb4KScanner::processShares()
return;
}
- else if ( (m_buffer.tqcontains( "Could not connect to server", true ) != 0 &&
- m_buffer.tqcontains( "The username or password was not correct.", true ) == 0) ||
- m_buffer.tqcontains( "Unable to find a suitable server" ) != 0 )
+ else if ( (m_buffer.contains( "Could not connect to server", true ) != 0 &&
+ m_buffer.contains( "The username or password was not correct.", true ) == 0) ||
+ m_buffer.contains( "Unable to find a suitable server" ) != 0 )
{
// We could not get the list of shares:
emit failed();
@@ -1232,19 +1232,19 @@ void Smb4KScanner::processShares()
{
TQString name, type, comment;
- if ( (*it).tqcontains( " Disk ", true ) != 0 )
+ if ( (*it).contains( " Disk ", true ) != 0 )
{
name = (*it).section( " Disk ", 0, 0 ).stripWhiteSpace();
type = "Disk";
comment = (*it).section( " Disk ", 1, 1 ).stripWhiteSpace();
}
- else if ( (*it).tqcontains( " Print ", true ) != 0 )
+ else if ( (*it).contains( " Print ", true ) != 0 )
{
name = (*it).section( " Print ", 0, 0 ).stripWhiteSpace();
type = "Printer";
comment = (*it).section( " Print ", 1, 1 ).stripWhiteSpace();
}
- else if ( (*it).tqcontains( " IPC ", true ) != 0 )
+ else if ( (*it).contains( " IPC ", true ) != 0 )
{
name = (*it).section( " IPC ", 0, 0 ).stripWhiteSpace();
type = "IPC";
@@ -1278,8 +1278,8 @@ void Smb4KScanner::processSearch()
// Stop right here if the user searched for illegal
// strings like #, ', () etc.
- if ( m_buffer.tqcontains( "Usage:", true ) != 0 ||
- m_buffer.tqcontains( "/bin/sh:", true ) != 0 )
+ if ( m_buffer.contains( "Usage:", true ) != 0 ||
+ m_buffer.contains( "/bin/sh:", true ) != 0 )
{
emit searchResult( new Smb4KHostItem() );
@@ -1298,7 +1298,7 @@ void Smb4KScanner::processSearch()
TQString workgroup = data.last().stripWhiteSpace();
TQString host, ip;
- if ( m_priv->host().tqcontains( ".", true ) != 3 )
+ if ( m_priv->host().contains( ".", true ) != 3 )
{
// The IP address is in the first entry:
ip = data.first().stripWhiteSpace().section( " ", 0, 0 );
@@ -1324,7 +1324,7 @@ void Smb4KScanner::processSearch()
{
if ( data.count() > 1 && !data[1].isEmpty() )
{
- if ( m_buffer.tqcontains( TQString( "Connection to %1 failed" ).tqarg( m_priv->host() ) ) != 0 )
+ if ( m_buffer.contains( TQString( "Connection to %1 failed" ).tqarg( m_priv->host() ) ) != 0 )
{
emit searchResult( new Smb4KHostItem() );
}
@@ -1377,7 +1377,7 @@ void Smb4KScanner::processInfo()
break;
}
- else if ( (*it).tqcontains( "Connection to", true ) != 0 )
+ else if ( (*it).contains( "Connection to", true ) != 0 )
{
// The lookup of the info failed:
emit failed();
@@ -913,11 +913,11 @@ void Smb4KScanner::processWorkgroupMembers()
{
- // If the IP address is empty, the shell output tqcontains
+ // If the IP address is empty, the shell output contains
// the IP address. Remove it, because it will confuse
// the user: